Snakemake Report

Loading Snakemake Report...

Please enable Javascript in your browser to see this report.

Loading 0 Bytes. For large reports, this can take a while.

## Workflow

Click the nodes to obtain details about each step.

## Statistics

If the workflow has been executed in cluster/cloud, runtimes include the waiting time in the queue.

Loading...

#####

##### Rule bgzip

Rule properties
Jobs | 1
Input files
{prefix}.vcf
Output files
{prefix}.vcf.gz
Conda software stack
htslib ==1.12
Code
     1
     2
     3
     4
     5
     6
     7
     8
     9
    10
    11
    12
    13
    14
    15
    16
    17
    __author__ = "William Rowell"
    __copyright__ = "Copyright 2020, William Rowell"
    __email__ = "wrowell@pacb.com"
    __license__ = "MIT"

    from snakemake.shell import shell

    extra = snakemake.params.get("extra", "")
    log = snakemake.log_fmt_shell(stdout=True, stderr=True)

    shell(
        """
        (bgzip -c {extra} --threads {snakemake.threads} \
            {snakemake.input} > {snakemake.output}) {log}
        """
    )

##### Rule b

Rule properties
Jobs | 1
Input files
{prefix}.txt
Output files
{prefix}.vcf
Code
    1
    2
    with open(snakemake.output[0], 'w') as f:
                f.write('bar')

##### Rule a

Rule properties
Jobs | 1
Output files
{prefix}.txt
Code
    1
    touch {output}